==> kubernetes-model-apiextensions-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrStringArrayFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface JSONSchemaPropsOrStringArrayFluent<A extends JSONSchemaPropsOrStringArrayFluent<A>> extends Fluent<A>{
  public A addToProperty(Integer index,String item);
  public A setToProperty(Integer index,String item);
  public A addToProperty(java.lang.String... items);
  public A addAllToProperty(Collection<String> items);
  public A removeFromProperty(java.lang.String... items);
  public A removeAllFromProperty(Collection<String> items);
  public List<String> getProperty();
  public String getProperty(Integer index);
  public String getFirstProperty();
  public String getLastProperty();
  public String getMatchingProperty(Predicate<String> predicate);
  public Boolean hasMatchingProperty(Predicate<String> predicate);
  public A withProperty(List<String> property);
  public A withProperty(java.lang.String... property);
  public Boolean hasProperty();
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @Deprecated
  public JSONSchemaProps getSchema();
  public JSONSchemaProps buildSchema();
  public A withSchema(JSONSchemaProps schema);
  public Boolean hasSchema();
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> withNewSchema();
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> withNewSchemaLike(JSONSchemaProps item);
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editSchema();
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editOrNewSchema();
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editOrNewSchemaLike(JSONSchemaProps item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SchemaNested<N> extends Nested<N>,JSONSchemaPropsFluent<JSONSchemaPropsOrStringArrayFluent.SchemaNested<N>>{
    public N and();
    public N endSchema();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrStringArrayFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface JSONSchemaPropsOrStringArrayFluent<A extends JSONSchemaPropsOrStringArrayFluent<A>> extends Fluent<A>{
  public A addToProperty(int index,String item);
  public A setToProperty(int index,String item);
  public A addToProperty(java.lang.String... items);
  public A addAllToProperty(Collection<String> items);
  public A removeFromProperty(java.lang.String... items);
  public A removeAllFromProperty(Collection<String> items);
  public List<String> getProperty();
  public String getProperty(int index);
  public String getFirstProperty();
  public String getLastProperty();
  public String getMatchingProperty(Predicate<String> predicate);
  public Boolean hasMatchingProperty(Predicate<String> predicate);
  public A withProperty(List<String> property);
  public A withProperty(java.lang.String... property);
  public Boolean hasProperty();
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @Deprecated
  public JSONSchemaProps getSchema();
  public JSONSchemaProps buildSchema();
  public A withSchema(JSONSchemaProps schema);
  public Boolean hasSchema();
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> withNewSchema();
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> withNewSchemaLike(JSONSchemaProps item);
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editSchema();
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editOrNewSchema();
  public JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editOrNewSchemaLike(JSONSchemaProps item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SchemaNested<N> extends Nested<N>,JSONSchemaPropsFluent<JSONSchemaPropsOrStringArrayFluent.SchemaNested<N>>{
    public N and();
    public N endSchema();
    
  }
  
}
